DateSelection class

Constructors

DateSelection({DateTime? startDate, DateTime? endDate, HalfDayType startHalf = HalfDayType.none, HalfDayType endHalf = HalfDayType.none})
const

Properties

endDate → DateTime?
final
endHalf → HalfDayType
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → DateTime?
final
startHalf → HalfDayType
final

Methods

copyWith({DateTime? startDate, DateTime? endDate, HalfDayType? startHalf, HalfDayType? endHalf}) → DateSelection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited